# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto.

Link do curso [Python pro](https://www.python.pro.br)

[![Build Status](https://travis-ci.com/heltonteixeira92/libpythonpro.svg?branch=main)](https://travis-ci.com/heltonteixeira92/libpythonpro)
[![Updates](https://pyup.io/repos/github/heltonteixeira92/libpythonpro/shield.svg)](https://pyup.io/repos/github/heltonteixeira92/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/heltonteixeira92/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/heltonteixeira92/libpythonpro/)

Para Instalar:

'''console
python -m venv .venv
.venv\Scripts\activate
pip install -r requirements-dev.txt
'''

Para conferir qualidade de código:
''' 
flake8
'''

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip